![lilbulb](assets/lilbulb.png)

Dave's lil' bulb - small function lib for creating ilidata.xml files and other utilities...

```
pip install lilbulb
```

```
>>> import lilbulb

>>> lilbulb.make_ilidata( path='.', project_name='daves_kbs15', owner='signedav@lilbulb.ws', dataset_version='2022-05-11', publishing_date='2022-05-31', linking_models=['KbS_V1_5'])
```